@@ -26,6 +26,7 @@ locust_runner = None
 STATE_INIT, STATE_HATCHING, STATE_RUNNING, STATE_STOPPED = ["ready", "hatching", "running", "stopped"]
 SLAVE_REPORT_INTERVAL = 3.0
 
+
 class LocustRunner(object):
     def __init__(self, locust_classes, hatch_rate, num_clients, num_requests=None, host=None):
         self.locust_classes = locust_classes
@@ -203,6 +204,10 @@ class DistributedLocustRunner(LocustRunner):
     def __init__(self, locust_classes, hatch_rate, num_clients, num_requests, host=None, master_host="localhost"):
         super(DistributedLocustRunner, self).__init__(locust_classes, hatch_rate, num_clients, num_requests, host)
         self.master_host = master_host
+    
+    def noop(self, *args, **kwargs):
+        """ Used to link() greenlets to in order to be compatible with gevent 1.0 """
+        pass
 
 class SlaveNode(object):
     def __init__(self, id, state=STATE_INIT):
@@ -238,7 +243,7 @@ class MasterLocustRunner(DistributedLocustRunner):
 
         self.server = rpc.Server()
         self.greenlet = Group()
-        self.greenlet.spawn(self.client_listener).link_exception()
+        self.greenlet.spawn(self.client_listener).link_exception(self.noop)
         
         # listener that gathers info on how many locust users the slaves has spawned
         def on_slave_report(client_id, data):
@@ -327,9 +332,9 @@ class SlaveLocustRunner(DistributedLocustRunner):
         
         self.client = rpc.Client(self.master_host)
         self.greenlet = Group()
-        self.greenlet.spawn(self.worker).link_exception()
+        self.greenlet.spawn(self.worker).link_exception(self.noop)
         self.client.send(Message("client_ready", None, self.client_id))
-        self.greenlet.spawn(self.stats_reporter).link_exception()
+        self.greenlet.spawn(self.stats_reporter).link_exception(self.noop)
         
         # register listener for when all locust users have hatched, and report it to the master node
         def on_hatch_complete(count):
