@@ -102,7 +102,7 @@ def request_stats_csv():
             '"Average response time"',
             '"Min response time"', 
             '"Max response time"',
-            '"Average Content-Length"',
+            '"Average Content Size"',
             '"Reqests/s"',
         ])
     ]
@@ -144,7 +144,10 @@ def distribution_stats_csv():
         '"100%"',
     ))]
     for s in chain(_sort_stats(runners.locust_runner.request_stats), [RequestStats.sum_stats("Total", full_request_history=True)]):
-        rows.append(s.percentile(tpl='"%s",%i,%i,%i,%i,%i,%i,%i,%i,%i,%i'))
+        if s.num_reqs:
+            rows.append(s.percentile(tpl='"%s",%i,%i,%i,%i,%i,%i,%i,%i,%i,%i'))
+        else:
+            rows.append('"%s",0,"N/A","N/A","N/A","N/A","N/A","N/A","N/A","N/A","N/A"' % s.name)
 
     response = make_response("\n".join(rows))
     file_name = "distribution_{0}.csv".format(time())
@@ -206,6 +209,12 @@ def request_stats():
         report = _request_stats_context_cache["report"]
     return json.dumps(report)
 
+@app.route("/exceptions")
+def exceptions():
+    response = make_response(json.dumps({'exceptions': [{"count": row["count"], "msg": row["msg"], "traceback": row["traceback"], "nodes" : ", ".join(row["nodes"])} for row in runners.locust_runner.exceptions.itervalues()]}))
+    response.headers["Content-type"] = "application/json"
+    return response
+
 def start(locust, hatch_rate, num_clients, num_requests, ramp):
     global _locust, _hatch_rate, _num_clients, _num_requests, _ramp
     _locust = locust
